Crate wacksy

Crate wacksy 

Reads WARC files and wraps them up into a WACZ archive.

let warc_file_path = std::path::Path::new("tests/example.warc.gz"); // set path to your WARC file
let wacz_object = WACZ::from_files(&[warc_file_path])?; // index the WARC and create a WACZ object - multiple WARC files can be specified here
let zipped_wacz: Vec<u8> = wacz_object.as_zip_archive()?; // zip up the WACZ
let mut wacz_file = fs::File::create("tests/example.wacz")?;
wacz_file.write_all(&zipped_wacz)?; // write out to file

Modules

datapackage
Structured representation of a datapackage.json file.
indexer

Structs

WACZ
A WACZ object

Enums

WaczError

Constants

WACZ_VERSION
Set the WACZ version of the file being created, deprecated in WACZ 1.2.0.